(function($) {
	"use strict";

	/**
	 * Preload images function
	 * @param {string} selector - The CSS selector for the images to be preloaded. Default is 'img'.
	 * @returns {Promise} A promise that resolves when all the images are loaded.
	 */
	const preloadImages = (selector = 'img') => {
		return new Promise((resolve) => {
			// Use the imagesLoaded library to ensure all images are fully loaded.
			imagesLoaded(document.querySelectorAll(selector), {background: true}, resolve);
		});
	};

	/** Direction constants */
	const NEXT = 1;
	const PREV = -1;

	/**
	 * Slideshow Class
	 * Manages slideshow functionality including navigation and animations.
	 * @export
	 */
	class Slideshow {

		/**
		 * Holds references to relevant DOM elements.
		 * @type {Object}
		 */
		DOM = {
			el: null,            // Main slideshow container
			slides: null,        // Individual slides
			slidesInner: null    // Inner content of slides (usually images)
		};
		/**
		 * Index of the current slide being displayed.
		 * @type {number}
		 */
		current = 0;
		/**
		 * Total number of slides.
		 * @type {number}
		 */
		slidesTotal = 0;

		/**  
		 * Flag to indicate if an animation is running.
		 * @type {boolean}
		 */
		isAnimating = false;
		
		/**
		 * Slideshow constructor.
		 * Initializes the slideshow and sets up the DOM elements.
		 * @param {HTMLElement} DOM_el - The main element holding all the slides.
		 */
		constructor(DOM_el) {
			// Initialize DOM elements
			this.DOM.el = DOM_el;
			this.DOM.slides = [...this.DOM.el.querySelectorAll('.ms--slide')];
			this.DOM.slidesInner = this.DOM.slides.map(item => item.querySelector('.ms--slide__img'));
			
			// Set initial slide as current
			this.DOM.slides[this.current].classList.add('ms--slide--current');
			
			// Count total slides
			this.slidesTotal = this.DOM.slides.length;
		}

		/**
		 * Navigate to the next slide.
		 * @returns {void}
		 */
		next() {
			this.navigate(NEXT);
		}

		/**
		 * Navigate to the previous slide.
		 * @returns {void}
		 */
		prev() {
			this.navigate(PREV);
		}

		/**
		 * Navigate through slides.
		 * @param {number} direction - The direction to navigate. 1 for next and -1 for previous.
		 * @returns {boolean} - Return false if the animation is currently running.
		 */
		navigate(direction) {  
			// Check if animation is already running
			if ( this.isAnimating ) return false;
			this.isAnimating = true;
			
			// Update the current slide index based on direction
			const previous = this.current;
			this.current = direction === 1 ? 
							this.current < this.slidesTotal - 1 ? ++this.current : 0 :
							this.current > 0 ? --this.current : this.slidesTotal - 1

			// Get the current and upcoming slides and their inner elements
			const currentSlide = this.DOM.slides[previous];
			const currentInner = this.DOM.slidesInner[previous];
			const upcomingSlide = this.DOM.slides[this.current];
			const upcomingInner = this.DOM.slidesInner[this.current];
			
			// Animation sequence using GSAP
			gsap
			.timeline({
				defaults: {
					duration: 1.5, 
					ease: 'power4.inOut'
				},
				onStart: () => {
					// Add class to the upcoming slide to mark it as current
					this.DOM.slides[this.current].classList.add('ms--slide--current');
				},
				onComplete: () => {
					// Remove class from the previous slide to unmark it as current
					this.DOM.slides[previous].classList.remove('ms--slide--current');
					// Reset animation flag
					this.isAnimating = false;
				}
			})
			// Defining animation steps
			.addLabel('start', 0)
			.to(currentSlide, {
				yPercent: -direction*100
			}, 'start')
			.to(currentInner, {
				yPercent: direction*30,
				startAt: {
					transformOrigin: direction === NEXT ? '0% 100%' : '100% 0%',
					rotation: 0
				},
				rotation: -direction*10,
				scaleY: 2.5
			}, 'start')
			.to(upcomingSlide, {
				startAt: {
					yPercent: direction*100 
				},
				yPercent: 0
			}, 'start')
			.to(upcomingInner, {
				startAt: {
					transformOrigin: direction === NEXT ? '0% 0%' : '100% 100%',
					yPercent: -direction*30, 
					scaleY: 2.5, 
					rotation: -direction*10
				},
				yPercent: 0,
				scaleY: 1,
				rotation: 0
			}, 'start');
		}

	}

	const slides = document.querySelector('.ms--slides');
	const slideshow = new Slideshow(slides);

	document.querySelector('.ms--slides-nav__item--prev').addEventListener('click', () => slideshow.prev());
	document.querySelector('.ms--slides-nav__item--next').addEventListener('click', () => slideshow.next());
	// Initialize the GSAP Observer plugin
	Observer.create({
		type: 'wheel,touch,pointer',
		onDown: () => slideshow.prev(),
		onUp: () => slideshow.next(),
		// invert the mouse wheel delta
		wheelSpeed: -1,
		tolerance: 10
	});

})(jQuery);